@@ -39,7 +39,7 @@ class MultilineContainers:
     """Ensure the consistency of multiline dict and list style."""
 
     name = 'flake8_multiline_containers'
-    version = '0.0.10'
+    version = '0.0.11'
 
     tree = attr.ib(default=None)
     filename = attr.ib(default="(none)")
@@ -153,8 +153,9 @@ class MultilineContainers:
 
         # Multiline container detected
         if open_times >= 1 and open_times != close_times:
-            for _ in range(open_times):
-                self.last_starts_at.append(get_left_pad(line))
+            self.last_starts_at.extend(
+                [get_left_pad(line)] * open_times,
+            )
 
             # Multiple opening characters
             if open_times > 1:
@@ -184,7 +185,7 @@ class MultilineContainers:
 
         """
         slices = [-1, -2, -3]
-        index = 0
+        index = get_left_pad(line)
 
         for s in slices:
             if line[s] == close_character:
@@ -230,7 +231,7 @@ class MultilineContainers:
                 close_times -= 1
                 self.function_depth -= 1
 
-        elif close_times > 0 and open_times == 0:
+        elif close_times > 0 and open_times == 0 and self.last_starts_at:
             index = self._get_closing_index(line, close_character)
 
             if index != self.last_starts_at[-1]:
